You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [14/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sou...

Modified: openoffice/trunk/main/framework/source/services/autorecovery.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/autorecovery.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/backingcomp.cxx (original)
+++ openoffice/trunk/main/framework/source/services/backingcomp.cxx Tue Apr 29 19:05:05 2014
@@ -376,7 +376,7 @@ css::uno::Reference< css::uno::XInterfac
 /** returns a new factory instance for instances of this class.
 
     It uses a helper class of the cppuhelper project as factory.
-    It will be initialized with all neccessary informations and
+    It will be initialized with all necessary informations and
     will be able afterwards to create instance of this class.
     This factory call us back inside our method impl_createInstance().
     So we can create and initialize ourself. Only filtering of creation
@@ -405,7 +405,7 @@ css::uno::Reference< css::lang::XSingleS
     attach this component to a target frame.
 
     We has to use the container window of this frame as parent window of our own component window.
-    But it's not allowed to work with it realy. May another component used it too.
+    But it's not allowed to work with it really. May another component used it too.
     Currently we need it only to create our child component window and support it's
     interfaces inside our queryInterface() method. The user of us must have e.g. the
     XWindow interface of it to be able to call setComponent(xWindow,xController) at the
@@ -542,7 +542,7 @@ void SAL_CALL BackingComp::attachFrame( 
     This component does not know any model. It will be represented by a window and
     it's controller only.
 
-    return  <FALSE/> everytime.
+    return  <FALSE/> every time.
  */
 
 sal_Bool SAL_CALL BackingComp::attachModel( /*IN*/ const css::uno::Reference< css::frame::XModel >& )
@@ -642,7 +642,7 @@ sal_Bool SAL_CALL BackingComp::suspend( 
     and inform us. We must release its reference only here. Of course we check the given reference
     here and reject callback from unknown sources.
 
-    Note: deregistration as listener isnt neccessary here. The broadcaster do it automaticly.
+    Note: deregistration as listener isn't necessary here. The broadcaster do it automatically.
 
     @param  aEvent
                 describe the broadcaster of this callback
@@ -764,7 +764,7 @@ void SAL_CALL BackingComp::addEventListe
 
 /** not supported.
 
-    Because registration is not supported too, we must do nothing here. Nobody can call this method realy.
+    Because registration is not supported too, we must do nothing here. Nobody can call this method really.
 
     @param  xListener
                 not used.
@@ -783,7 +783,7 @@ void SAL_CALL BackingComp::removeEventLi
     Inside attachFrame() we created our component window. But it was not allowed there, to
     initialitze it. E.g. the menu must be set at the container window of the frame, which
     is our parent window. But may at that time another component used it.
-    That's why our creator has to inform us, when it's time to initialize us realy.
+    That's why our creator has to inform us, when it's time to initialize us really.
     Currently only calling of this method must be done. But further implementatoins
     can use special in parameter to configure this initialization ...
 

Modified: openoffice/trunk/main/framework/source/services/backingwindow.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/backingwindow.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/backingwindow.cxx (original)
+++ openoffice/trunk/main/framework/source/services/backingwindow.cxx Tue Apr 29 19:05:05 2014
@@ -482,7 +482,7 @@ void BackingWindow::initControls()
 
     nYPos += (maProductSize.Height()*3)/2;
 
-    // set a slighly larger font than normal labels on the texts
+    // set a slightly larger font than normal labels on the texts
     maTextFont.SetSize( Size( 0, 11 ) );
     maTextFont.SetWeight( WEIGHT_NORMAL );
 

Modified: openoffice/trunk/main/framework/source/services/desktop.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/desktop.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/modulemanager.cxx (original)
+++ openoffice/trunk/main/framework/source/services/modulemanager.cxx Tue Apr 29 19:05:05 2014
@@ -171,7 +171,7 @@ ModuleManager::~ModuleManager()
     
     if (sModule.getLength() < 1)
         throw css::frame::UnknownModuleException(
-                ::rtl::OUString::createFromAscii("Cant find suitable module for the given component."),
+                ::rtl::OUString::createFromAscii("Can't find suitable module for the given component."),
                 static_cast< ::cppu::OWeakObject* >(this));
     
     return sModule;
@@ -205,7 +205,7 @@ void SAL_CALL ModuleManager::replaceByNa
     // get access to the element
     // Note: Dont use impl_getConfig() method here. Because it creates a readonly access only, further
     // it cache it as a member of this module manager instance. If we change some props there ... but dont
-    // flush changes (because an error occured) we will read them later. If we use a different config access
+    // flush changes (because an error occurred) we will read them later. If we use a different config access
     // we can close it without a flush ... and our read data wont be affected .-)
     css::uno::Reference< css::uno::XInterface >         xCfg      = ::comphelper::ConfigurationHelper::openConfig(
                                                                         xSMGR,

Modified: openoffice/trunk/main/framework/source/services/pathsettings.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/pathsettings.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/substitutepathvars.cxx (original)
+++ openoffice/trunk/main/framework/source/services/substitutepathvars.cxx Tue Apr 29 19:05:05 2014
@@ -98,7 +98,7 @@
 #define REPLACELENGTH_LANGID             9
 #define REPLACELENGTH_VLANG              8
 #define REPLACELENGTH_WORKDIRURL        13
-// --> PB 2004-10-27 #i32656# - new variable of hierachy service
+// --> PB 2004-10-27 #i32656# - new variable of hierarchy service
 #define REPLACELENGTH_BASEINSTURL       14
 #define REPLACELENGTH_USERDATAURL       14
 // <--
@@ -121,7 +121,7 @@
 #define VARIABLE_PROGURL                                "$(progurl)"
 #define VARIABLE_USERURL                                "$(userurl)"
 #define VARIABLE_WORKDIRURL                             "$(workdirurl)"
-// --> PB 2004-10-27 #i32656# - new variable of hierachy service
+// --> PB 2004-10-27 #i32656# - new variable of hierarchy service
 #define VARIABLE_BASEINSTURL                            "$(baseinsturl)"
 #define VARIABLE_USERDATAURL                            "$(userdataurl)"
 // <--
@@ -213,7 +213,7 @@ static FixedVariable aFixedVarTable[] =
     { VARIABLE_PROGURL,     PREDEFVAR_PROGURL,      REPLACELENGTH_PROGURL,  true                       },
     { VARIABLE_USERURL,     PREDEFVAR_USERURL,      REPLACELENGTH_USERURL,  true                       },
     { VARIABLE_WORKDIRURL,  PREDEFVAR_WORKDIRURL,   REPLACELENGTH_WORKDIRURL,true                      },  // Special variable (transient) and don't use for resubstitution!
-    // --> PB 2004-10-27 #i32656# - new variable of hierachy service
+    // --> PB 2004-10-27 #i32656# - new variable of hierarchy service
     { VARIABLE_BASEINSTURL, PREDEFVAR_BASEINSTURL,  REPLACELENGTH_BASEINSTURL,true                     },
     { VARIABLE_USERDATAURL, PREDEFVAR_USERDATAURL,  REPLACELENGTH_USERDATAURL,true                     },
     // <--
@@ -957,12 +957,12 @@ throw ( NoSuchElementException, RuntimeE
     // Fill return value with result
     if ( bSubstitutionCompleted )
     {
-        // Substitution successfull!
+        // Substitution successful!
         aResult = aWorkText;
     }
     else
     {
-        // Substitution not successfull!
+        // Substitution not successful!
         if ( nDepth == nMaxRecursiveDepth )
         {
             // recursion depth reached!
@@ -1182,14 +1182,14 @@ void SubstitutePathVariables::SetPredefi
     // Set $(inst), $(instpath), $(insturl)
     aPreDefPathVariables.m_FixedVar[ PREDEFVAR_INSTURL ]    = aPreDefPathVariables.m_FixedVar[ PREDEFVAR_INSTPATH ];
     aPreDefPathVariables.m_FixedVar[ PREDEFVAR_INST ]       = aPreDefPathVariables.m_FixedVar[ PREDEFVAR_INSTPATH ];
-    // --> PB 2004-10-27 #i32656# - new variable of hierachy service
+    // --> PB 2004-10-27 #i32656# - new variable of hierarchy service
     aPreDefPathVariables.m_FixedVar[ PREDEFVAR_BASEINSTURL ]= aPreDefPathVariables.m_FixedVar[ PREDEFVAR_INSTPATH ];
     // <--
 
     // Set $(user), $(userpath), $(userurl)
     aPreDefPathVariables.m_FixedVar[ PREDEFVAR_USERURL ]    = aPreDefPathVariables.m_FixedVar[ PREDEFVAR_USERPATH ];
     aPreDefPathVariables.m_FixedVar[ PREDEFVAR_USER ]       = aPreDefPathVariables.m_FixedVar[ PREDEFVAR_USERPATH ];
-    // --> PB 2004-11-11 #i32656# - new variable of hierachy service
+    // --> PB 2004-11-11 #i32656# - new variable of hierarchy service
     aPreDefPathVariables.m_FixedVar[ PREDEFVAR_USERDATAURL ]= aPreDefPathVariables.m_FixedVar[ PREDEFVAR_USERPATH ];
     // <--
 

Modified: openoffice/trunk/main/framework/source/services/taskcreatorsrv.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/taskcreatorsrv.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/taskcreatorsrv.cxx (original)
+++ openoffice/trunk/main/framework/source/services/taskcreatorsrv.cxx Tue Apr 29 19:05:05 2014
@@ -175,7 +175,7 @@ css::uno::Reference< css::uno::XInterfac
     //------------------->
     // HACK  #125187# + #i53630#
     // Mark all document windows as "special ones", so VCL can bind
-    // special features to it. Because VCL doesnt know anything about documents ...
+    // special features to it. Because VCL doesn't know anything about documents ...
     // Note: Doing so it's no longer supported, that e.g. our wizards can use findFrame(_blank)
     // to create it's previes frames. They must do it manually by using WindowDescriptor+Toolkit!
     css::uno::Reference< css::frame::XDesktop > xDesktop(xParentFrame, css::uno::UNO_QUERY);
@@ -246,7 +246,7 @@ css::uno::Reference< css::awt::XWindow >
     // get toolkit to create task container window
     css::uno::Reference< css::awt::XToolkit > xToolkit( xSMGR->createInstance( SERVICENAME_VCLTOOLKIT ), css::uno::UNO_QUERY_THROW);
 
-    // Check if child frames can be created realy. We need at least a valid window at the parent frame ...
+    // Check if child frames can be created really. We need at least a valid window at the parent frame ...
     css::uno::Reference< css::awt::XWindowPeer > xParentWindowPeer;
     if ( ! bTopWindow)
     {
@@ -315,7 +315,7 @@ css::uno::Reference< css::frame::XFrame 
     xNewFrame->initialize( xContainerWindow );
 
     // Put frame to the frame tree.
-    // Note: The property creator/parent will be set on the new putted frame automaticly ... by the parent container.
+    // Note: The property creator/parent will be set on the new putted frame automatically ... by the parent container.
 	if (xParentFrame.is())
 	{
 		css::uno::Reference< css::frame::XFramesSupplier > xSupplier  (xParentFrame, css::uno::UNO_QUERY_THROW);

Modified: openoffice/trunk/main/framework/source/tabwin/tabwindow.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/tabwin/tabwindow.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/tabwin/tabwindow.cxx (original)
+++ openoffice/trunk/main/framework/source/tabwin/tabwindow.cxx Tue Apr 29 19:05:05 2014
@@ -908,7 +908,7 @@ void SAL_CALL TabWindow::getFastProperty
         if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
             static ::cppu::OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;

Modified: openoffice/trunk/main/framework/source/uiconfiguration/moduleuicfgsupplier.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uiconfiguration/moduleuicfgsupplier.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uiconfiguration/moduleuicfgsupplier.cxx (original)
+++ openoffice/trunk/main/framework/source/uiconfiguration/moduleuicfgsupplier.cxx Tue Apr 29 19:05:05 2014
@@ -192,7 +192,7 @@ RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "fr
         m_xUserCfgRootStorage = Reference< XStorage >( xStorageFactory->createInstanceWithArguments( aArgs ), UNO_QUERY );
 
         // Create wrapper object for module user interface configuration managers, so they are able to call commit/revert on
-        // root storage and nothing more (saftey)!
+        // root storage and nothing more (safety)!
         RootStorageWrapper* pUserRootStorageWrapper = new RootStorageWrapper( Reference< XTransactedObject >( m_xUserCfgRootStorage, UNO_QUERY ));
         m_xUserRootCommit = Reference< XTransactedObject>( static_cast< OWeakObject *>( pUserRootStorageWrapper ), UNO_QUERY );
     }

Modified: openoffice/trunk/main/framework/source/uiconfiguration/moduleuiconfigurationmanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uiconfiguration/moduleuiconfigurationmanager.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uiconfiguration/moduleuiconfigurationmanager.cxx (original)
+++ openoffice/trunk/main/framework/source/uiconfiguration/moduleuiconfigurationmanager.cxx Tue Apr 29 19:05:05 2014
@@ -419,7 +419,7 @@ ModuleUIConfigurationManager::UIElementD
         }
     }
     
-    // Not successfull, we have to look into our default vector/hash_map combination
+    // Not successful, we have to look into our default vector/hash_map combination
     UIElementDataHashMap& rDefaultHashMap = m_aUIElements[LAYER_DEFAULT][nElementType].aElementsHashMap;
     pIter = rDefaultHashMap.find( aResourceURL );
     if ( pIter != rDefaultHashMap.end() )

Modified: openoffice/trunk/main/framework/source/uiconfiguration/uicategorydescription.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uiconfiguration/uicategorydescription.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uiconfiguration/uicategorydescription.cxx (original)
+++ openoffice/trunk/main/framework/source/uiconfiguration/uicategorydescription.cxx Tue Apr 29 19:05:05 2014
@@ -94,7 +94,7 @@ namespace framework
 //	Configuration access class for PopupMenuControllerFactory implementation
 //*****************************************************************************************************************
 
-class ConfigurationAccess_UICategory : // Order is neccessary for right initialization!
+class ConfigurationAccess_UICategory : // Order is necessary for right initialization!
                                         private ThreadHelpBase                           ,
                                         public  ::cppu::WeakImplHelper2<XNameAccess,XContainerListener>
 {
@@ -166,7 +166,7 @@ ConfigurationAccess_UICategory::Configur
     m_bCacheFilled( sal_False )
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "framework", "Ocke.Janssen@sun.com", "ConfigurationAccess_UICategory::ConfigurationAccess_UICategory" );
-    // Create configuration hierachical access name
+    // Create configuration hierarchical access name
     m_aConfigCategoryAccess += aModuleName;
     m_aConfigCategoryAccess += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CONFIGURATION_CATEGORY_ELEMENT_ACCESS ));
 

Modified: openoffice/trunk/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.cxx (original)
+++ openoffice/trunk/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.cxx Tue Apr 29 19:05:05 2014
@@ -391,7 +391,7 @@ UIConfigurationManagerImpl::UIElementDat
     
     if ( m_bUseDefault )
     {
-        // Not successfull, we have to look into our default vector/hash_map combination
+        // Not successful, we have to look into our default vector/hash_map combination
         UIElementDataHashMap& rDefaultHashMap = m_aUIElements[LAYER_DEFAULT][nElementType].aElementsHashMap;
         pIter = rDefaultHashMap.find( aResourceURL );
         if ( pIter != rDefaultHashMap.end() )

Modified: openoffice/trunk/main/framework/source/uiconfiguration/windowstateconfiguration.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uiconfiguration/windowstateconfiguration.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uiconfiguration/windowstateconfiguration.cxx (original)
+++ openoffice/trunk/main/framework/source/uiconfiguration/windowstateconfiguration.cxx Tue Apr 29 19:05:05 2014
@@ -141,7 +141,7 @@ class ConfigurationAccess_WindowState : 
                                         public  XNameContainer                           ,
                                         public  XContainerListener                       ,
                                         // baseclasses
-							            // Order is neccessary for right initialization!
+							            // Order is necessary for right initialization!
                                         private ThreadHelpBase                           ,
                                         public  ::cppu::OWeakObject
 {
@@ -210,7 +210,7 @@ class ConfigurationAccess_WindowState : 
             WINDOWSTATE_MASK_DOCKSIZE       = 32768
         };
 
-        // Cache structure. Valid values are described by tje eMask member. All other values should not be
+        // Cache structure. Valid values are described by the eMask member. All other values should not be
         // provided to outside code!
         struct WindowStateInfo
         {
@@ -296,7 +296,7 @@ ConfigurationAccess_WindowState::Configu
     m_bConfigAccessInitialized( sal_False ),
     m_bModified( sal_False )
 {
-    // Create configuration hierachical access name
+    // Create configuration hierarchical access name
     m_aConfigWindowAccess += aModuleName;
     m_aConfigWindowAccess += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CONFIGURATION_WINDOWSTATE_ACCESS ));
     m_xConfigProvider = Reference< XMultiServiceFactory >( rServiceManager->createInstance( SERVICENAME_CFGPROVIDER ), UNO_QUERY );

Modified: openoffice/trunk/main/framework/source/uielement/popuptoolbarcontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uielement/popuptoolbarcontroller.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uielement/popuptoolbarcontroller.cxx (original)
+++ openoffice/trunk/main/framework/source/uielement/popuptoolbarcontroller.cxx Tue Apr 29 19:05:05 2014
@@ -339,7 +339,7 @@ void NewToolbarController::functionExecu
     If the given URL can be located as an action command of one menu item of the
     popup menu of this control, we return sal_True. Otherwhise we return sal_False.
     Further we return a fallback URL, in case we have to return sal_False. Because
-    the outside code must select a valid item of the popup menu everytime ...
+    the outside code must select a valid item of the popup menu every time ...
     and we define it here. By the way this m ethod was written to handle
     error situations gracefully. E.g. it can be called during creation time
     but then we have no valid menu. For this case we know another fallback URL.
@@ -347,7 +347,7 @@ void NewToolbarController::functionExecu
 
     @param  rPopupMenu
                 pounts to the popup menu, on which item we try to locate the given URL
-                Can be NULL! Search will be supressed then.
+                Can be NULL! Search will be suppressed then.
 
     @param  sURL
                 the URL for searching

Modified: openoffice/trunk/main/framework/source/uielement/uicommanddescription.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uielement/uicommanddescription.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uielement/uicommanddescription.cxx (original)
+++ openoffice/trunk/main/framework/source/uielement/uicommanddescription.cxx Tue Apr 29 19:05:05 2014
@@ -106,7 +106,7 @@ namespace framework
 //	Configuration access class for PopupMenuControllerFactory implementation
 //*****************************************************************************************************************
 
-class ConfigurationAccess_UICommand : // Order is neccessary for right initialization!
+class ConfigurationAccess_UICommand : // Order is necessary for right initialization!
                                         private ThreadHelpBase                           ,
                                         public  ::cppu::WeakImplHelper2<XNameAccess,XContainerListener>
 {
@@ -224,7 +224,7 @@ ConfigurationAccess_UICommand::Configura
     m_bCacheFilled( sal_False ),
     m_bGenericDataRetrieved( sal_False )
 {
-    // Create configuration hierachical access name
+    // Create configuration hierarchical access name
     m_aConfigCmdAccess += aModuleName;
     m_aConfigCmdAccess += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CONFIGURATION_CMD_ELEMENT_ACCESS ));
 

Modified: openoffice/trunk/main/framework/source/unotypes/fwk.xml
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/unotypes/fwk.xml?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/unotypes/fwk.xml (original)
+++ openoffice/trunk/main/framework/source/unotypes/fwk.xml Tue Apr 29 19:05:05 2014
@@ -113,7 +113,7 @@
 		<description>
 			It's a dispatch object which can handle "mailto:" URLs.
 			This service is registered in configuration for this protocol
-			and wil be used automaticly by the generic dispatch implementation
+			and wil be used automatically by the generic dispatch implementation
 			of a Frame. It should start an external mail application and forward
 			this request to it.
 		</description>
@@ -128,10 +128,10 @@
 		<name> com.sun.star.comp.framework.ServiceHandler </name>
 		<description>
 			It's a special dispatch object which is registered for "service:*" URL pattern
-			and will be automaticly used by the framework dispatch mechanism if such URL occured.
+			and will be automatically used by the framework dispatch mechanism if such URL occurred.
             His job is to create any registered uno components which must be coded inside
             dispatched URL (may with some optional given parameters). After that such created
-            service must be hold his self alive. Such mechanism can be usefull for UI components
+            service must be hold his self alive. Such mechanism can be useful for UI components
             (e.g. Dialogs, Wizards) only.
 		</description>
 		<loader-name> com.sun.star.loader.SharedLibrary </loader-name>
@@ -145,7 +145,7 @@
         <name> com.sun.star.comp.framework.JobHandler </name>
         <description>
             It's a special dispatch object which is registered for "vnd.sun.star.job:*" URL pattern
-            and will be automaticly used by the framework dispatch mechanism if such URL occured.
+            and will be automatically used by the framework dispatch mechanism if such URL occurred.
             It binds the dispatch mechanism to the generic job execution of this framework module.
             That can be used for e.g. addon purposes.
         </description>

Modified: openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx (original)
+++ openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx Tue Apr 29 19:05:05 2014
@@ -55,7 +55,7 @@ namespace framework{
    structure was detected.
    
    This macro combined the given comment with a generic
-   way to find out the XML line (where the error occured)
+   way to find out the XML line (where the error occurred)
    to format a suitable message.
    
    @param   COMMENT
@@ -131,7 +131,7 @@ void SAL_CALL AcceleratorConfigurationRe
     if (eElement == E_ELEMENT_ITEM)
     {
         if (!m_bInsideAcceleratorList)
-            THROW_PARSEEXCEPTION("An element \"accel:item\" must be embeded into 'accel:acceleratorlist'.")
+            THROW_PARSEEXCEPTION("An element \"accel:item\" must be embedded into 'accel:acceleratorlist'.")
         if (m_bInsideAcceleratorItem)
             THROW_PARSEEXCEPTION("An element \"accel:item\" is not a container.")
         m_bInsideAcceleratorItem = sal_True;
@@ -189,7 +189,7 @@ void SAL_CALL AcceleratorConfigurationRe
         #ifdef ENABLE_WARNINGS
         else
         {
-            // Attention: Its not realy a reason to throw an exception and kill the office, if the configuration contains
+            // Attention: Its not really a reason to throw an exception and kill the office, if the configuration contains
             // multiple registrations for the same key :-) Show a warning ... and ignore the second item.
             // THROW_PARSEEXCEPTION("Command is registered for the same key more then once.")
             ::rtl::OUStringBuffer sMsg(256);

Modified: openoffice/trunk/main/framework/source/xml/imagesdocumenthandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/xml/imagesdocumenthandler.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/test/test.cxx (original)
+++ openoffice/trunk/main/framework/test/test.cxx Tue Apr 29 19:05:05 2014
@@ -186,7 +186,7 @@ void TestApplication::Main()
 	m_xFactory = aManager.getGlobalUNOServiceManager();
 	setProcessServiceFactory( m_xFactory );
 
-	// Control sucess of operation.
+	// Control success of operation.
 	LOG_ASSERT( !(m_xFactory.is()			==sal_False	), "TestApplication::Main()\nCan't create global service manager.\n\n"			)
 	LOG_ASSERT( !(getProcessServiceFactory()!=m_xFactory), "TestApplication::Main()\nGlobal servicemanager not set in UNOTOOLS.\n\n"	)
 
@@ -616,7 +616,7 @@ void TestApplication::impl_testDesktop( 
 	LOG_ASSERT( !(xDesktopFrame->getName()!=sName), "TestApplication::impl_testDesktop()\nSetting of name works not correct on desktop.\n\n" )
 
 	//	Reset name do default!
-	//	Its neccessary for follow operations.
+	//	Its necessary for follow operations.
 	sName = OUString( RTL_CONSTASCII_USTRINGPARAM("Desktop") );
 	xDesktopFrame->setName( sName );
 
@@ -1304,7 +1304,7 @@ sal_Bool TestApplication::impl_testTreeS
 	}
 
 	// Test inside/outside tasks search
-	// No frames outside current task should be found if TASKS flag isnt set.
+	// No frames outside current task should be found if TASKS flag isn't set.
 	// Otherwise he must be found!
 	if	(
 			( xF21211->findFrame( DECLARE_ASCII("F12"	),	FrameSearchFlag::ALL								)		== xF12		)	||
--- openoffice/trunk/main/framework/source/services/autorecovery.cxx (original)
+++ openoffice/trunk/main/framework/source/services/autorecovery.cxx Tue Apr 29 19:05:05 2014
@@ -225,7 +225,7 @@ static const sal_Int32       GIVE_UP_RET
 
 // enable the following defines in case you whish to simulate a full disc for debug purposes .-)
 
-// this define throws everytime a document is stored or a configuration change
+// this define throws every time a document is stored or a configuration change
 // should be flushed an exception ... so the special error handler for this scenario is triggered
 // #define TRIGGER_FULL_DISC_CHECK
 
@@ -624,10 +624,10 @@ void SAL_CALL AutoRecovery::dispatch(con
     ::comphelper::SequenceAsHashMap lArgs(lArguments);
 
     // check if somewhere wish to disable recovery temp. for this office session
-    // This can be done immediatly ... must not been done asynchronous.
+    // This can be done immediately ... must not been done asynchronous.
     if ((eNewJob & AutoRecovery::E_DISABLE_AUTORECOVERY) == AutoRecovery::E_DISABLE_AUTORECOVERY)
     {
-        // it's important to set a flag internaly, so AutoRecovery will be supressed - even if it's requested.
+        // it's important to set a flag internaly, so AutoRecovery will be suppressed - even if it's requested.
         m_eJob |= eNewJob;
         implts_stopTimer();
         implts_stopListening();
@@ -873,8 +873,8 @@ void SAL_CALL AutoRecovery::notifyEvent(
         implts_updateModifiedState(xDocument);
     }
     /* at least one document starts saving process =>
-       Our application code isnt ready for multiple save requests
-       at the same time. So we have to supress our AutoSave feature
+       Our application code isn't ready for multiple save requests
+       at the same time. So we have to suppress our AutoSave feature
        for the moment, till this other save requests will be finished.
      */
     else
@@ -899,7 +899,7 @@ void SAL_CALL AutoRecovery::notifyEvent(
     /* document saved as copy => mark it as "non used by concurrent save operation".
        so we can try to create a backup copy if next time AutoSave is started too.
        Dont remove temp. files or change the modified state of the document!
-       It was not realy saved to the original file ...
+       It was not really saved to the original file ...
     */
     else
     if (aEvent.EventName.equals(EVENT_ON_SAVETODONE))
@@ -978,7 +978,7 @@ void SAL_CALL AutoRecovery::changesOccur
 
     // Note: This call stops the timer and starts it again.
     // But it checks the different timer states internaly and
     // may be supress the restart!
     implts_updateTimer();
 }
 
@@ -1063,7 +1063,7 @@ css::uno::Reference< css::container::XNa
     catch(const css::uno::Exception&)
         {
             // These config keys are not sooooo important, that
             // we are interested on errors here realy .-)
             nMinSpaceDocSave    = MIN_DISCSPACE_DOCSAVE;
             nMinSpaceConfigSave = MIN_DISCSPACE_CONFIGSAVE;
         }
@@ -1211,7 +1211,7 @@ void AutoRecovery::implts_specifyDefault
     if (!rInfo.AppModule.getLength())
     {
         throw css::uno::RuntimeException(
-                ::rtl::OUString::createFromAscii("Cant find out the default filter and its extension, if no application module is known!"),
+                ::rtl::OUString::createFromAscii("Can't find out the default filter and its extension, if no application module is known!"),
                 static_cast< css::frame::XDispatch* >(this));
     }
 
@@ -1271,7 +1271,7 @@ void AutoRecovery::implts_specifyAppModu
 {
     ENSURE_OR_THROW2(
         rInfo.AppModule.getLength() || rInfo.Document.is(),
-        "Cant find out the application module nor its factory URL, if no application module (or a suitable) document is known!",
+        "Can't find out the application module nor its factory URL, if no application module (or a suitable) document is known!",
         *this );
 
     // SAFE -> ----------------------------------
@@ -1427,7 +1427,7 @@ void AutoRecovery::implts_flushConfigIte
         catch(const css::uno::Exception& ex)
             {
                 // a) FULL DISC seams to be the problem behind                              => show error and retry it forever (e.g. retry=300)
-                // b) unknown problem (may be locking problem)                              => reset RETRY value to more usefull value(!) (e.g. retry=3)
+                // b) unknown problem (may be locking problem)                              => reset RETRY value to more useful value(!) (e.g. retry=3)
                 // c) unknown problem (may be locking problem) + 1..2 repeating operations  => throw the original exception to force generation of a stacktrace !
 
                 // SAFE ->
@@ -1682,7 +1682,7 @@ IMPL_LINK(AutoRecovery, implts_timerExpi
         sal_Bool bAllowUserIdleLoop = sal_True;
         AutoRecovery::ETimerType eSuggestedTimer = implts_saveDocs(bAllowUserIdleLoop, sal_False);
 
         // If timer isnt used for "short callbacks" (means polling
         // for special states) ... reset the handle state of all
         // cache items. Such handle state indicates, that a document
         // was already saved during the THIS(!) AutoSave session.
@@ -1803,7 +1803,7 @@ void AutoRecovery::implts_registerDocume
     implts_specifyAppModuleAndFactory(aNew);
 
     // Hack! Check for "illegal office documents" ... as e.g. the Basic IDE
     // Its not realy a full featured office document. It doesnt provide an URL, any filter, a factory URL etcpp.
     // TODO file bug to Basci IDE developers. They must remove the office document API from its service.
     if (
         (!aNew.OrgURL.getLength()    ) &&
@@ -1881,7 +1881,7 @@ void AutoRecovery::implts_deregisterDocu
     aCacheLock.unlock();
 
     // Sometimes we close documents by ourself.
-    // And these documents cant be deregistered.
+    // And these documents can't be deregistered.
     // Otherwhise we loos our configuration data ... but need it !
     // see SessionSave !
     if (aInfo.IgnoreClosing)
@@ -1899,7 +1899,7 @@ void AutoRecovery::implts_deregisterDocu
 
     /* This method is called within disposing() of the document too. But there it's not a good idea to
        deregister us as listener. Furter it make no sense - because the broadcaster dies.
-       So we supress deregistration in such case ...
+       So we suppress deregistration in such case ...
     */
     if (bStopListening)
         implts_stopModifyListeningOnDoc(aInfo);
@@ -2200,7 +2200,7 @@ void AutoRecovery::implts_prepareSession
         So we have to check a second time, if this property is set ....
         Best place doing so is to check it immeditaly before saving
         and supressingd saving the document then.
-        Of course removing the corresponding cache entry isnt an option.
+        Of course removing the corresponding cache entry isn't an option.
         Because it would disturb iteration over the cache !
         So we ignore such documents only ...
         Hopefully next time they are not inserted in our cache.
@@ -2304,11 +2304,11 @@ AutoRecovery::ETimerType AutoRecovery::i
         // ii)  For a CrashSave ... add it to the list of dangerous documents and
         //      save it after all other documents was saved successfully. That decrease
         //      the chance for a crash inside a crash.
-        //      On the other side it's not neccessary for documents, which are not modified.
+        //      On the other side it's not necessary for documents, which are not modified.
         //      They can be handled normaly - means we patch the corresponding configuration entry only.
         // iii) For a SessionSave ... ignore it! There is no time to wait for this save operation.
         //      Because the WindowManager will kill the process if it doesnt react immediatly.
         //      On the other side we cant risk a concurrent save request ... because we know
         //      that it will produce a crash.
 
         // Attention: Because eJob is used as a flag field, you have to check for the worst case first.
@@ -2460,7 +2460,7 @@ void AutoRecovery::implts_saveOneDoc(con
                 bError = sal_True;
 
                 // a) FULL DISC seams to be the problem behind                              => show error and retry it forever (e.g. retry=300)
-                // b) unknown problem (may be locking problem)                              => reset RETRY value to more usefull value(!) (e.g. retry=3)
+                // b) unknown problem (may be locking problem)                              => reset RETRY value to more useful value(!) (e.g. retry=3)
                 // c) unknown problem (may be locking problem) + 1..2 repeating operations  => throw the original exception to force generation of a stacktrace !
 
                 // SAFE ->
@@ -2500,12 +2500,12 @@ void AutoRecovery::implts_saveOneDoc(con
         rInfo.DocumentState |=  AutoRecovery::E_INCOMPLETE;
     }
 
     // make sure the progress isnt referred any longer
     impl_forgetProgress(rInfo, lNewArgs, css::uno::Reference< css::frame::XFrame >());
 
     // try to remove the old temp file.
     // Ignore any error here. We have a new temp file, which is up to date.
-    // The only thing is: we fill the disk with temp files, if we cant remove old ones :-)
+    // The only thing is: we fill the disk with temp files, if we can't remove old ones :-)
     ::rtl::OUString sRemoveFile      = rInfo.OldTempURL;
                     rInfo.OldTempURL = rInfo.NewTempURL;
                     rInfo.NewTempURL = ::rtl::OUString();
@@ -2700,7 +2700,7 @@ AutoRecovery::ETimerType AutoRecovery::i
         /* Normaly we listen as XModifyListener on a document to know if a document was changed
            since our last AutoSave. And we deregister us in case we know this state.
            But directly after one document as recovered ... we must start listening.
-           Otherwhise the first "modify" doesnt reach us. Because we ourself called setModified()
+           Otherwise the first "modify" doesn't reach us. Because we ourselves called setModified()
            on the document via API. And currently we dont listen for any events (not at the GlobalEventBroadcaster
            nor at any document!).
         */
@@ -2853,7 +2853,7 @@ void AutoRecovery::implts_generateNewTem
     // This unique name must solve an optimization problem too!
     // In case we are asked to save unmodified documents too - and one of them
     // is an empty one (because it was new created using e.g. an URL private:factory/...)
     // we should not save it realy. Then we put the information about such "empty document"
     // into the configuration and dont create any recovery file on disk.
     // We use the title of the document to make it unique.
     ::rtl::OUStringBuffer sUniqueName;
@@ -3053,10 +3053,10 @@ void AutoRecovery::implts_resetHandleSta
 //-----------------------------------------------
 void AutoRecovery::implts_prepareEmergencySave()
 {
     // Be sure to know all open documents realy .-)
     implts_verifyCacheAgainstDesktopDocumentList();
 
-    // hide all docs, so the user cant disturb our emergency save .-)
+    // hide all docs, so the user can't disturb our emergency save .-)
     implts_changeAllDocVisibility(sal_False);
 }
 
@@ -3081,7 +3081,7 @@ void AutoRecovery::implts_doEmergencySav
     // during normal AutoSave more then once. Because
     // it postpone active documents and save it later.
     // That is normaly done by recalling it from a timer.
-    // Here we must do it immediatly!
+    // Here we must do it immediately!
     // Of course this method returns the right state -
     // because it knows, that we are running in ERMERGENCY SAVE mode .-)
 
@@ -3141,7 +3141,7 @@ void AutoRecovery::implts_doSessionSave(
 {
     LOG_RECOVERY("AutoRecovery::implts_doSessionSave()")
 
     // Be sure to know all open documents realy .-)
     implts_verifyCacheAgainstDesktopDocumentList();
 
     // for all docs, store their current view/names in the configurtion
@@ -3151,7 +3151,7 @@ void AutoRecovery::implts_doSessionSave(
     // during normal AutoSave more then once. Because
     // it postpone active documents and save it later.
     // That is normaly done by recalling it from a timer.
-    // Here we must do it immediatly!
+    // Here we must do it immediately!
     // Of course this method returns the right state -
     // because it knows, that we are running in SESSION SAVE mode .-)
 
@@ -3377,7 +3377,7 @@ void SAL_CALL AutoRecovery::getFastPrope
 
                     sal_Bool bRecoveryData = ((sal_Bool)(m_lDocCache.size()>0));
 
-                    // exists session data ... => then we cant say, that these
+                    // exists session data ... => then we can't say, that these
                     // data are valid for recovery. So we have to return sal_False then!
                     if (bSessionData)
                         bRecoveryData = sal_False;
@@ -3590,7 +3590,7 @@ void AutoRecovery::impl_establishProgres
     // for loading documents into this frame)!
     // But if no frame exists ... we can try to locate it using any frame bound to the provided
     // document. Of course we must live without any frame in case the document does not exists at this
-    // point. But this state shouldnt occure. In such case xNewFrame should be valid ... hopefully .-)
+    // point. But this state shouldn't occure. In such case xNewFrame should be valid ... hopefully .-)
     css::uno::Reference< css::frame::XFrame > xFrame = xNewFrame;
     if (
         (!xFrame.is()       ) &&
@@ -3629,7 +3629,7 @@ void AutoRecovery::impl_establishProgres
     // So we use a two step mechanism:
     // 1) we set the progress inside the MediaDescriptor, which will be provided to the filter
     // 2) and we set a special Frame property, which overwrites the normal behaviour of Frame::createStatusIndicator .-)
     // But we supress 2) in case we uses an internal progress. Because then it doesnt matter
     // if our applications make it wrong. In such case the internal progress resists at the same frame
     // and there is no need to forward progress activities to e.g. an outside dialog .-)
     if (
@@ -3656,7 +3656,7 @@ void AutoRecovery::impl_forgetProgress(c
     // for loading documents into this frame)!
     // But if no frame exists ... we can try to locate it using any frame bound to the provided
     // document. Of course we must live without any frame in case the document does not exists at this
-    // point. But this state shouldnt occure. In such case xNewFrame should be valid ... hopefully .-)
+    // point. But this state shouldn't occure. In such case xNewFrame should be valid ... hopefully .-)
     css::uno::Reference< css::frame::XFrame > xFrame = xNewFrame;
     if (
         (!xFrame.is()       ) &&
@@ -978,7 +978,7 @@ void SAL_CALL AutoRecovery::changesOccur
     // Note: This call stops the timer and starts it again.
     // But it checks the different timer states internaly and
-    // may be supress the restart!
+    // may be suppress the restart!
     implts_updateTimer();
 }
@@ -1063,7 +1063,7 @@ css::uno::Reference< css::container::XNa
         {
             // These config keys are not sooooo important, that
-            // we are interested on errors here realy .-)
+            // we are interested on errors here really .-)
             nMinSpaceDocSave    = MIN_DISCSPACE_DOCSAVE;
             nMinSpaceConfigSave = MIN_DISCSPACE_CONFIGSAVE;
@@ -1682,7 +1682,7 @@ IMPL_LINK(AutoRecovery, implts_timerExpi
         AutoRecovery::ETimerType eSuggestedTimer = implts_saveDocs(bAllowUserIdleLoop, sal_False);
 
-        // If timer isnt used for "short callbacks" (means polling
+        // If timer isn't used for "short callbacks" (means polling
         // for special states) ... reset the handle state of all
         // cache items. Such handle state indicates, that a document
@@ -1803,7 +1803,7 @@ void AutoRecovery::implts_registerDocume
 
     // Hack! Check for "illegal office documents" ... as e.g. the Basic IDE
-    // Its not realy a full featured office document. It doesnt provide an URL, any filter, a factory URL etcpp.
+    // Its not really a full featured office document. It doesn't provide an URL, any filter, a factory URL etcpp.
     // TODO file bug to Basci IDE developers. They must remove the office document API from its service.
     if (
@@ -2304,11 +2304,11 @@ AutoRecovery::ETimerType AutoRecovery::i
         //      They can be handled normaly - means we patch the corresponding configuration entry only.
         // iii) For a SessionSave ... ignore it! There is no time to wait for this save operation.
-        //      Because the WindowManager will kill the process if it doesnt react immediatly.
-        //      On the other side we cant risk a concurrent save request ... because we know
+        //      Because the WindowManager will kill the process if it doesn't react immediately.
+        //      On the other side we can't risk a concurrent save request ... because we know
         //      that it will produce a crash.
 
@@ -2500,12 +2500,12 @@ void AutoRecovery::implts_saveOneDoc(con
     }
 
-    // make sure the progress isnt referred any longer
+    // make sure the progress isn't referred any longer
     impl_forgetProgress(rInfo, lNewArgs, css::uno::Reference< css::frame::XFrame >());
 
@@ -2853,7 +2853,7 @@ void AutoRecovery::implts_generateNewTem
     // In case we are asked to save unmodified documents too - and one of them
     // is an empty one (because it was new created using e.g. an URL private:factory/...)
-    // we should not save it realy. Then we put the information about such "empty document"
+    // we should not save it really. Then we put the information about such "empty document"
     // into the configuration and dont create any recovery file on disk.
     // We use the title of the document to make it unique.
@@ -3053,10 +3053,10 @@ void AutoRecovery::implts_resetHandleSta
 void AutoRecovery::implts_prepareEmergencySave()
 {
-    // Be sure to know all open documents realy .-)
+    // Be sure to know all open documents really .-)
     implts_verifyCacheAgainstDesktopDocumentList();
 
@@ -3141,7 +3141,7 @@ void AutoRecovery::implts_doSessionSave(
     LOG_RECOVERY("AutoRecovery::implts_doSessionSave()")
 
-    // Be sure to know all open documents realy .-)
+    // Be sure to know all open documents really .-)
     implts_verifyCacheAgainstDesktopDocumentList();
 
@@ -3629,7 +3629,7 @@ void AutoRecovery::impl_establishProgres
     // 1) we set the progress inside the MediaDescriptor, which will be provided to the filter
     // 2) and we set a special Frame property, which overwrites the normal behaviour of Frame::createStatusIndicator .-)
-    // But we supress 2) in case we uses an internal progress. Because then it doesnt matter
+    // But we suppress 2) in case we uses an internal progress. Because then it doesn't matter
     // if our applications make it wrong. In such case the internal progress resists at the same frame
     // and there is no need to forward progress activities to e.g. an outside dialog .-)

Modified: openoffice/trunk/main/framework/source/services/backingcomp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/backingcomp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/desktop.cxx (original)
+++ openoffice/trunk/main/framework/source/services/desktop.cxx Tue Apr 29 19:05:05 2014
@@ -221,7 +221,7 @@ DEFINE_INIT_SERVICE                     
 
     @attention  a)  Don't use your own reference during an UNO-Service-ctor! There is no guarantee, that you
                     will get over this. (e.g. using of your reference as parameter to initialize some member)
-                    Do such things in DEFINE_INIT_SERVICE() method, which is called automaticly after your ctor!!!
+                    Do such things in DEFINE_INIT_SERVICE() method, which is called automatically after your ctor!!!
                 b)  Baseclass OBroadcastHelper is a typedef in namespace cppu!
                     The microsoft compiler has some problems to handle it right BY using namespace explicitly ::cppu::OBroadcastHelper.
                     If we write it without a namespace or expand the typedef to OBrodcastHelperVar<...> -> it will be OK!?
@@ -416,7 +416,7 @@ sal_Bool SAL_CALL Desktop::terminate()
         if ( xPipeTerminator.is() )
             xPipeTerminator->notifyTermination( aEvent );
         
         // Must be realy the last listener to be called.
         // Because it shutdown the whole process asynchronous !
         if ( xSfxTerminator.is() )
             xSfxTerminator->notifyTermination( aEvent );
@@ -579,7 +579,7 @@ css::uno::Reference< css::lang::XCompone
 /*-************************************************************************************************************//**
     @interface  XDesktop
     @short      return the current active frame in hierarchy
-    @descr      There can be more then one different active pathes in our frame hierarchy. But only one of them
+    @descr      There can be more then one different active paths in our frame hierarchy. But only one of them
                 could be the most active frame (normal he has the focus).
                 Don't mix it with getActiveFrame()! That will return our current active frame, which must be
                 a direct child of us and should be a part(!) of an active path.
@@ -658,7 +658,7 @@ css::uno::Reference< css::lang::XCompone
 /*-************************************************************************************************************//**
     @interface  XTasksSupplier
     @short      get access to create enumerations of ouer taskchilds
-    @descr      Direct childs of desktop are tasks everytime.
+    @descr      Direct childs of desktop are tasks every time.
                 Call these method to could create enumerations of it.
 
 But; Don't forget - you will be the owner of returned object and must release it!
@@ -779,7 +779,7 @@ css::uno::Sequence< css::uno::Reference<
     @short      supports registration/deregistration of interception objects, which
                 are interested on special dispatches.
 
-    @descr      Its realy provided by an internal helper, which is used inside the dispatch api too.
+    @descr      Its really provided by an internal helper, which is used inside the dispatch api too.
     @param      xInterceptor
                 the interceptor object, which wish to be (de)registered.
 
@@ -857,7 +857,7 @@ void SAL_CALL Desktop::setActiveFrame( c
     // If nothing will change - do nothing!
     // Otherwise set new active frame ...
     // and deactivate last frame.
-    // It's neccessary for our FrameActionEvent listener on a frame!
+    // It's necessary for our FrameActionEvent listener on a frame!
     css::uno::Reference< css::frame::XFrame > xLastActiveChild = m_aChildTaskContainer.getActive();
     if( xLastActiveChild != xFrame )
 	{
@@ -1053,7 +1053,7 @@ css::uno::Reference< css::frame::XFrame 
     //    force using of "if() else if() ..."
     //-----------------------------------------------------------------------------------------------------
 
-    // get threadsafe some neccessary member which are neccessary for following functionality
+    // get threadsafe some necessary member which are necessary for following functionality
     /* SAFE { */
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::lang::XMultiServiceFactory > xFactory = m_xFactory;
@@ -1063,7 +1063,7 @@ css::uno::Reference< css::frame::XFrame 
     //-----------------------------------------------------------------------------------------------------
     // I.I) "_blank"
     //  create a new task as child of this desktop instance
     //  Note: Used helper TaskCreator use us automaticly ...
     //-----------------------------------------------------------------------------------------------------
     if ( sTargetFrameName==SPECIALTARGET_BLANK )
     {
@@ -1102,10 +1102,10 @@ css::uno::Reference< css::frame::XFrame 
         //  But we ust break further searches if target was already found.
         //  Order of using flags is fix: SELF - CHILDREN - SIBLINGS - PARENT
         //  TASK and CREATE are handled special.
-        //  But note: Such flags are not valid for the desktop - especialy SIBLINGS or PARENT.
+        //  But note: Such flags are not valid for the desktop - especially SIBLINGS or PARENT.
         //-------------------------------------------------------------------------------------------------
 
-        // get threadsafe some neccessary member which are neccessary for following functionality
+        // get threadsafe some necessary member which are necessary for following functionality
         /* SAFE { */
         aReadLock.lock();
         ::rtl::OUString sOwnName = m_sName;
@@ -1129,9 +1129,9 @@ css::uno::Reference< css::frame::XFrame 
         // II.II) TASKS
         //  This is a special flag. Normaly it regulate search inside tasks and forbid access to parent trees.
         //  But the desktop exists outside such task trees. They are our sub trees. So the desktop implement
         //  a special feature: We use it to start search on our direct childrens only. That means we supress
         //  search on ALL child frames. May that can be usefull to get access on opened document tasks
         //  only without filter out all non realy required sub frames ...
         //  Used helper method on our container doesn't create any frame - its a search only.
         //-------------------------------------------------------------------------------------------------
         if (
@@ -1160,7 +1160,7 @@ css::uno::Reference< css::frame::XFrame 
         //-------------------------------------------------------------------------------------------------
         // II.IV) CREATE
         //  If we haven't found any valid target frame by using normal flags - but user allowed us to create
         //  a new one ... we should do that. Used TaskCreator use us automaticly as parent!
         //-------------------------------------------------------------------------------------------------
         if (
             ( ! xTarget.is()                                   )    &&
@@ -1187,12 +1187,12 @@ void SAL_CALL Desktop::dispose()
         WriteGuard aWriteLock( m_aLock );
     
         // Look for multiple calls of this method!
         // If somewhere call dispose() twice - he will be stopped here realy!!!
         TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
     
         // Now - we are alone and its the first call of this method ...
         // otherwise call before had thrown a DisposedException / hopefully .-)
-        // But we dont use the transaction object created before ... we reset it immediatly ...
+        // But we dont use the transaction object created before ... we reset it immediately ...
         // two lines of code ... for what ?
         // The answer: We wished to synchronize concurrent dispose() calls -> OK
         // But next line will wait for all currently running transaction (even if they
@@ -1211,7 +1211,7 @@ void SAL_CALL Desktop::dispose()
     // Following lines of code can be called outside a synchronized block ...
     // Because our transaction manager will block all new requests to this object.
     // So nobody can use us any longer.
-    // Exception: Only removing of listener will work ... and this code cant be dangerous.
+    // Exception: Only removing of listener will work ... and this code can't be dangerous.
 
     // First we has to kill all listener connections.
     // They might rely on our member and can hinder us on releasing them.
@@ -1328,7 +1328,7 @@ void SAL_CALL Desktop::dispatchFinished(
 /*-************************************************************************************************************//**
     @interface  XEventListener
     @short      not implemented!
-    @descr      We are a status listener ... and so we must be an event listener too ... But we doesn't need it realy!
+    @descr      We are a status listener ... and so we must be an event listener too ... But we doesn't need it really!
                 We are a temp. listener only and our lifetime isn't smaller then of our temp. used dispatcher.
 
     @seealso    method loadComponentFromURL()
@@ -1346,7 +1346,7 @@ void SAL_CALL Desktop::disposing( const 
 
 /*-************************************************************************************************************//**
     @interface  XInteractionHandler
-    @short      callback for loadComponentFromURL for detected exceptions during load proccess
+    @short      callback for loadComponentFromURL for detected exceptions during load process
     @descr      In this case we must cancel loading and throw these detected exception again as result
                 of our own called method.
 
@@ -1437,7 +1437,7 @@ void SAL_CALL Desktop::handle( const css
 
     /* SAFE AREA ------------------------------------------------------------------------------------------- */
     // Ok now it's time to break yield loop of loadComponentFromURL().
     // But only for realy aborted requests!
     // For example warnings will be approved and we wait for any success story ...
     if (bAbort)
     {
@@ -1490,7 +1490,7 @@ void SAL_CALL Desktop::releaseNumberForC
                 Don't use this directly!
                 You must try to convert the value of given DESKTOP_PROPHANDLE and
                 return results of this operation. This will be used to ask vetoable
-                listener. If no listener has a veto, we will change value realy!
+                listener. If no listener has a veto, we will change value really!
                 ( in method setFastPropertyValue_NoBroadcast(...) )
 
     @attention  Methods of OPropertySethelper are safed by using our shared osl mutex! (see ctor!)
@@ -1555,7 +1555,7 @@ sal_Bool SAL_CALL Desktop::convertFastPr
     @descr      This method is calling from helperclass "OPropertySetHelper".
                 Don't use this directly!
                 Handle and value are valid everyway! You must set the new value only.
-                After this, baseclass send messages to all listener automaticly.
+                After this, baseclass send messages to all listener automatically.
 
     @seealso    class OPropertySetHelper
 
@@ -1658,7 +1658,7 @@ void SAL_CALL Desktop::getFastPropertyVa
         if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
             static ::cppu::OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;
@@ -1956,7 +1956,7 @@ void Desktop::impl_sendNotifyTermination
                     // Reactivate controller.
                     // It can happen that XController.suspend() returned true ... but a registered close listener
                     // throwed these veto exception. Then the controller has to be reactivated. Otherwise
-                    // these document doesnt work any more.
+                    // these document doesn't work any more.
                     if (
                         (bSuspended      ) &&
                         (xController.is())
@@ -416,7 +416,7 @@ sal_Bool SAL_CALL Desktop::terminate()
             xPipeTerminator->notifyTermination( aEvent );
         
-        // Must be realy the last listener to be called.
+        // Must be really the last listener to be called.
         // Because it shutdown the whole process asynchronous !
         if ( xSfxTerminator.is() )
@@ -1063,7 +1063,7 @@ css::uno::Reference< css::frame::XFrame 
     // I.I) "_blank"
     //  create a new task as child of this desktop instance
-    //  Note: Used helper TaskCreator use us automaticly ...
+    //  Note: Used helper TaskCreator use us automatically ...
     //-----------------------------------------------------------------------------------------------------
     if ( sTargetFrameName==SPECIALTARGET_BLANK )
@@ -1129,9 +1129,9 @@ css::uno::Reference< css::frame::XFrame 
         //  This is a special flag. Normaly it regulate search inside tasks and forbid access to parent trees.
         //  But the desktop exists outside such task trees. They are our sub trees. So the desktop implement
-        //  a special feature: We use it to start search on our direct childrens only. That means we supress
-        //  search on ALL child frames. May that can be usefull to get access on opened document tasks
-        //  only without filter out all non realy required sub frames ...
+        //  a special feature: We use it to start search on our direct childrens only. That means we suppress
+        //  search on ALL child frames. May that can be useful to get access on opened document tasks
+        //  only without filter out all non really required sub frames ...
         //  Used helper method on our container doesn't create any frame - its a search only.
         //-------------------------------------------------------------------------------------------------
@@ -1160,7 +1160,7 @@ css::uno::Reference< css::frame::XFrame 
         // II.IV) CREATE
         //  If we haven't found any valid target frame by using normal flags - but user allowed us to create
-        //  a new one ... we should do that. Used TaskCreator use us automaticly as parent!
+        //  a new one ... we should do that. Used TaskCreator use us automatically as parent!
         //-------------------------------------------------------------------------------------------------
         if (
@@ -1187,12 +1187,12 @@ void SAL_CALL Desktop::dispose()
     
         // Look for multiple calls of this method!
-        // If somewhere call dispose() twice - he will be stopped here realy!!!
+        // If somewhere call dispose() twice - he will be stopped here really!!!
         TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
     
@@ -1437,7 +1437,7 @@ void SAL_CALL Desktop::handle( const css
     /* SAFE AREA ------------------------------------------------------------------------------------------- */
     // Ok now it's time to break yield loop of loadComponentFromURL().
-    // But only for realy aborted requests!
+    // But only for really aborted requests!
     // For example warnings will be approved and we wait for any success story ...
     if (bAbort)

Modified: openoffice/trunk/main/framework/source/services/frame.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/frame.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/frame.cxx (original)
+++ openoffice/trunk/main/framework/source/services/frame.cxx Tue Apr 29 19:05:05 2014
@@ -257,7 +257,7 @@ DEFINE_INIT_SERVICE                 (   
 
     @attention  a)  Don't use your own reference during an UNO-Service-ctor! There is no guarantee, that you
                     will get over this. (e.g. using of your reference as parameter to initialize some member)
-                    Do such things in DEFINE_INIT_SERVICE() method, which is called automaticly after your ctor!!!
+                    Do such things in DEFINE_INIT_SERVICE() method, which is called automatically after your ctor!!!
                 b)  Baseclass OBroadcastHelper is a typedef in namespace cppu!
                     The microsoft compiler has some problems to handle it right BY using namespace explicitly ::cppu::OBroadcastHelper.
                     If we write it without a namespace or expand the typedef to OBrodcastHelperVar<...> -> it will be OK!?
@@ -426,7 +426,7 @@ css::uno::Reference< css::frame::XFrame 
     ReadGuard aReadLock( m_aLock );
 
 	// Return current active frame.
-	// This information is avaliable on the container.
+	// This information is available on the container.
 	return m_aChildFrameContainer.getActive();
 }
 
@@ -455,7 +455,7 @@ void SAL_CALL Frame::setActiveFrame( con
 	/* SAFE AREA ----------------------------------------------------------------------------------------------- */
     WriteGuard aWriteLock( m_aLock );
 
     // Copy neccessary member for threadsafe access!
     // m_aChildFrameContainer is threadsafe himself and he live if we live!!!
     // ...and our transaction is non breakable too ...
     css::uno::Reference< css::frame::XFrame > xActiveChild = m_aChildFrameContainer.getActive();
@@ -572,7 +572,7 @@ void SAL_CALL Frame::initialize( const c
 
     if ( m_xContainerWindow.is() )
         throw css::uno::RuntimeException(
-                ::rtl::OUString::createFromAscii("Frame::initialized() is called more then once, which isnt usefull nor allowed."),
+                ::rtl::OUString::createFromAscii("Frame::initialized() is called more then once, which isn't useful nor allowed."),
                 static_cast< css::frame::XFrame* >(this));
 
     // Look for rejected calls first!
@@ -816,7 +816,7 @@ css::uno::Reference< css::frame::XFrame 
     //    force using of "if() else if() ..."
     //-----------------------------------------------------------------------------------------------------
 
     // get threadsafe some neccessary member which are neccessary for following functionality
     /* SAFE { */
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::frame::XFrame >              xParent      ( m_xParent, css::uno::UNO_QUERY );
@@ -829,7 +829,7 @@ css::uno::Reference< css::frame::XFrame 
     //-----------------------------------------------------------------------------------------------------
     // I.I) "_blank"
     //  Not allowed for a normal frame - but for the desktop.
     //  Use helper class to do so. It use the desktop automaticly.
     //-----------------------------------------------------------------------------------------------------
     if ( sTargetFrameName==SPECIALTARGET_BLANK )
     {
@@ -914,7 +914,7 @@ css::uno::Reference< css::frame::XFrame 
         //  TASK and CREATE are handled special.
         //-------------------------------------------------------------------------------------------------
 
         // get threadsafe some neccessary member which are neccessary for following functionality
         /* SAFE { */
         aReadLock.lock();
         ::rtl::OUString sOwnName = m_sName;
@@ -964,7 +964,7 @@ css::uno::Reference< css::frame::XFrame 
             //-------------------------------------------------------------------------------------------------
             // II.III.I) SIBLINGS
             //  Search on all our direct siblings - means all childrens of our parent.
-            //  Use this flag in combination with TASK. We must supress such upper search if
+            //  Use this flag in combination with TASK. We must suppress such upper search if
             //  user has not set it and if we are a top frame.
             //
             //  Attention: Don't forward this request to our parent as a findFrame() call.
@@ -1040,7 +1040,7 @@ css::uno::Reference< css::frame::XFrame 
         //-------------------------------------------------------------------------------------------------
         // II.IV) CREATE
         //  If we haven't found any valid target frame by using normal flags - but user allowed us to create
         //  a new one ... we should do that. Used TaskCreator use Desktop instance automaticly as parent!
         //-------------------------------------------------------------------------------------------------
         if (
             ( ! xTarget.is()                                   )    &&
@@ -1088,7 +1088,7 @@ sal_Bool SAL_CALL Frame::isTop() throw( 
 
 /*-****************************************************************************************************//**
 	@short		activate frame in hierarchy
-	@descr		This feature is used to mark active pathes in our frame hierarchy.
+	@descr		This feature is used to mark active paths in our frame hierarchy.
 				You can be a listener for this event to react for it ... change some internal states or something else.
 
 	@seealso	method deactivate()
@@ -1110,8 +1110,8 @@ void SAL_CALL Frame::activate() throw( c
 	/* SAFE AREA ----------------------------------------------------------------------------------------------- */
     WriteGuard aWriteLock( m_aLock );
 
     // Copy neccessary member and free the lock.
     // It's not neccessary for m_aChildFrameContainer ... because
     // he is threadsafe himself and live if we live.
     // We use a registered transaction to prevent us against
     // breaks during this operation!
@@ -1136,7 +1136,7 @@ void SAL_CALL Frame::activate() throw( c
         // Deactivate sibling path and forward activation to parent ... if any parent exist!
         if( xParent.is() == sal_True )
         {
-            // Everytime set THIS frame as active child of parent and activate it.
+            // Every time set THIS frame as active child of parent and activate it.
             // We MUST have a valid path from bottom to top as active path!
             // But we must deactivate the old active sibling path first.
 
@@ -1151,7 +1151,7 @@ void SAL_CALL Frame::activate() throw( c
             // But we do nothing then! We are already activated.
             xParent->activate();
         }
         // Its neccessary to send event NOW - not before.
         // Activation goes from bottom to top!
         // Thats the reason to activate parent first and send event now.
         implts_sendFrameActionEvent( css::frame::FrameAction_FRAME_ACTIVATED );
@@ -1188,7 +1188,7 @@ void SAL_CALL Frame::activate() throw( c
 
 /*-****************************************************************************************************//**
 	@short		deactivate frame in hierarchy
-	@descr		This feature is used to deactive pathes in our frame hierarchy.
+	@descr		This feature is used to deactive paths in our frame hierarchy.
 				You can be a listener for this event to react for it ... change some internal states or something else.
 
 	@seealso	method activate()
@@ -1210,7 +1210,7 @@ void SAL_CALL Frame::deactivate() throw(
 	/* SAFE AREA ----------------------------------------------------------------------------------------------- */
     WriteGuard aWriteLock( m_aLock );
 
     // Copy neccessary member and free the lock.
     css::uno::Reference< css::frame::XFrame >           xActiveChild    = m_aChildFrameContainer.getActive()                                     ;
     css::uno::Reference< css::frame::XFramesSupplier >  xParent         ( m_xParent, css::uno::UNO_QUERY )                                ;
     css::uno::Reference< css::frame::XFrame >           xThis           ( static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY );
@@ -1893,7 +1893,7 @@ void SAL_CALL Frame::dispose() throw( cs
     // should exist. Otherwhise it's the problem of the outside caller.
     // Note:
     //      (a) Do it after stopWindowListening(). May that force some active/deactive
     //          notifications which we doesn't need here realy.
     //      (b) Don't forget to save the old value of IsDialogCancelEnabled() to
     //          restore it afterwards. We cannot call EnableDialogCancel( sal_False )
     //          as we would kill the headless mode!
@@ -1972,7 +1972,7 @@ void SAL_CALL Frame::dispose() throw( cs
     m_bSelfClose         = sal_False;
     m_bIsHidden          = sal_True;
 
     // Disable this instance for further working realy!
     m_aTransactionManager.setWorkingMode( E_CLOSE );
 
     // Don't forget it restore old value -
@@ -2042,7 +2042,7 @@ css::uno::Reference< css::task::XStatusI
 	/* SAFE AREA ----------------------------------------------------------------------------------------------- */
     ReadGuard aReadLock( m_aLock );
 
     // Make snapshot of neccessary member and define default return value.
     css::uno::Reference< css::task::XStatusIndicator >        xExternal(m_xIndicatorInterception.get(), css::uno::UNO_QUERY);
     css::uno::Reference< css::task::XStatusIndicatorFactory > xFactory = m_xIndicatorFactoryHelper;
 
@@ -2388,7 +2388,7 @@ void SAL_CALL Frame::windowClosing( cons
 
 /*-****************************************************************************************************//**
     @short      react for a show event for the internal container window
-    @descr      Normaly we doesn't need this information realy. But we can use it to
+    @descr      Normaly we doesn't need this information really. But we can use it to
                 implement the special feature "trigger first visible task".
 
                 Algorithm: - first we have to check if we are a top (task) frame
@@ -2483,7 +2483,7 @@ void SAL_CALL Frame::disposing( const cs
 
     if( aEvent.Source == m_xContainerWindow )
     {
         // NECCESSARY: Impl-method is threadsafe by himself!
         aWriteLock.unlock();
         implts_stopWindowListening();
         aWriteLock.lock();
@@ -2858,7 +2858,7 @@ void Frame::implts_setIconOnWindow()
     TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
 
 	/* SAFE AREA ----------------------------------------------------------------------------------------------- */
     // Make snapshot of neccessary members and release lock.
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::awt::XWindow >       xContainerWindow( m_xContainerWindow, css::uno::UNO_QUERY );
     css::uno::Reference< css::frame::XController > xController     ( m_xController     , css::uno::UNO_QUERY );
@@ -2937,9 +2937,9 @@ void Frame::implts_setIconOnWindow()
 
 /*-************************************************************************************************************//**
     @short      helper to start/stop listeneing for window events on container window
-    @descr      If we get a new container window, we must set it on internal memeber ...
+    @descr      If we get a new container window, we must set it on internal member ...
                 and stop listening at old one ... and start listening on new one!
-                But sometimes (in dispose() call!) it's neccessary to stop listeneing without starting
+                But sometimes (in dispose() call!) it's necessary to stop listeneing without starting
                 on new connections. So we split this functionality to make it easier at use.
 
     @seealso    method initialize()
@@ -2957,7 +2957,7 @@ void Frame::implts_startWindowListening(
     TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
 
     /* SAFE AREA ----------------------------------------------------------------------------------------------- */
     // Make snapshot of neccessary member!
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::awt::XWindow >                            xContainerWindow    = m_xContainerWindow   ;
     css::uno::Reference< css::lang::XMultiServiceFactory >              xFactory            = m_xFactory           ;
@@ -3000,7 +3000,7 @@ void Frame::implts_stopWindowListening()
     TransactionGuard aTransaction( m_aTransactionManager, E_SOFTEXCEPTIONS );
 
     /* SAFE AREA ----------------------------------------------------------------------------------------------- */
     // Make snapshot of neccessary member!
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::awt::XWindow >                            xContainerWindow    = m_xContainerWindow   ;
     css::uno::Reference< css::lang::XMultiServiceFactory >              xFactory            = m_xFactory           ;
@@ -3061,7 +3061,7 @@ void Frame::implts_checkSuicide()
     aReadLock.unlock();
     /* } SAFE */
     // force close and deliver owner ship to source of possible throwed veto exception
-    // Attention: Because this method isn't designed to throw such exception we must supress
+    // Attention: Because this method isn't designed to throw such exception we must suppress
     // it for outside code!
     try
     {
@@ -3089,7 +3089,7 @@ void Frame::implts_checkSuicide()
 void Frame::impl_setCloser( /*IN*/ const css::uno::Reference< css::frame::XFrame >& xFrame ,
                             /*IN*/       sal_Bool                                   bState  )
 {
     // Note: If start module isnt installed - no closer has to be shown!
     if (!SvtModuleOptions().IsModuleInstalled(SvtModuleOptions::E_SSTARTMODULE))
         return;
 
@@ -3124,7 +3124,7 @@ void Frame::impl_checkMenuCloser()
     ReadGuard aReadLock(m_aLock);
 
     // only top frames, which are part of our desktop hierarchy, can
-    // do so! By the way - we need the desktop instance to have acess
+    // do so! By the way - we need the desktop instance to have access
     // to all other top level frames too.
     css::uno::Reference< css::frame::XDesktop >        xDesktop     (m_xParent, css::uno::UNO_QUERY);
     css::uno::Reference< css::frame::XFramesSupplier > xTaskSupplier(xDesktop , css::uno::UNO_QUERY);
@@ -3150,7 +3150,7 @@ void Frame::impl_checkMenuCloser()
     // If there exist ate least one other frame - there are two frames currently open.
     // But we can enable this closer only, if one of these two tasks includes the help module.
     // The "other frame" couldn't be the help. Because then it wouldn't be part of this "other list".
-    // In such case it will be seperated to the reference aAnalyzer.m_xHelp!
+    // In such case it will be separated to the reference aAnalyzer.m_xHelp!
     // But we must check, if weself includes the help ...
     // Check aAnalyzer.m_bReferenceIsHelp!
     if (
@@ -3180,7 +3180,7 @@ void Frame::impl_checkMenuCloser()
         xNewCloserFrame = this;
     }
 
     // Look for neccessary actions ...
     // Only if the closer state must be moved from one frame to another one
     // or must be enabled/disabled at all.
     /* STATIC SAFE { */
@@ -455,7 +455,7 @@ void SAL_CALL Frame::setActiveFrame( con
     WriteGuard aWriteLock( m_aLock );
 
-    // Copy neccessary member for threadsafe access!
+    // Copy necessary member for threadsafe access!
     // m_aChildFrameContainer is threadsafe himself and he live if we live!!!
     // ...and our transaction is non breakable too ...
@@ -816,7 +816,7 @@ css::uno::Reference< css::frame::XFrame 
     //-----------------------------------------------------------------------------------------------------
 
-    // get threadsafe some neccessary member which are neccessary for following functionality
+    // get threadsafe some necessary member which are necessary for following functionality
     /* SAFE { */
     ReadGuard aReadLock( m_aLock );
@@ -829,7 +829,7 @@ css::uno::Reference< css::frame::XFrame 
     // I.I) "_blank"
     //  Not allowed for a normal frame - but for the desktop.
-    //  Use helper class to do so. It use the desktop automaticly.
+    //  Use helper class to do so. It use the desktop automatically.
     //-----------------------------------------------------------------------------------------------------
     if ( sTargetFrameName==SPECIALTARGET_BLANK )
@@ -914,7 +914,7 @@ css::uno::Reference< css::frame::XFrame 
         //-------------------------------------------------------------------------------------------------
 
-        // get threadsafe some neccessary member which are neccessary for following functionality
+        // get threadsafe some necessary member which are necessary for following functionality
         /* SAFE { */
         aReadLock.lock();
@@ -1040,7 +1040,7 @@ css::uno::Reference< css::frame::XFrame 
         // II.IV) CREATE
         //  If we haven't found any valid target frame by using normal flags - but user allowed us to create
-        //  a new one ... we should do that. Used TaskCreator use Desktop instance automaticly as parent!
+        //  a new one ... we should do that. Used TaskCreator use Desktop instance automatically as parent!
         //-------------------------------------------------------------------------------------------------
         if (
@@ -1110,8 +1110,8 @@ void SAL_CALL Frame::activate() throw( c
     WriteGuard aWriteLock( m_aLock );
 
-    // Copy neccessary member and free the lock.
-    // It's not neccessary for m_aChildFrameContainer ... because
+    // Copy necessary member and free the lock.
+    // It's not necessary for m_aChildFrameContainer ... because
     // he is threadsafe himself and live if we live.
     // We use a registered transaction to prevent us against
@@ -1151,7 +1151,7 @@ void SAL_CALL Frame::activate() throw( c
             xParent->activate();
         }
-        // Its neccessary to send event NOW - not before.
+        // Its necessary to send event NOW - not before.
         // Activation goes from bottom to top!
         // Thats the reason to activate parent first and send event now.
@@ -1210,7 +1210,7 @@ void SAL_CALL Frame::deactivate() throw(
     WriteGuard aWriteLock( m_aLock );
 
-    // Copy neccessary member and free the lock.
+    // Copy necessary member and free the lock.
     css::uno::Reference< css::frame::XFrame >           xActiveChild    = m_aChildFrameContainer.getActive()                                     ;
     css::uno::Reference< css::frame::XFramesSupplier >  xParent         ( m_xParent, css::uno::UNO_QUERY )                                ;
@@ -1893,7 +1893,7 @@ void SAL_CALL Frame::dispose() throw( cs
     // Note:
     //      (a) Do it after stopWindowListening(). May that force some active/deactive
-    //          notifications which we doesn't need here realy.
+    //          notifications which we doesn't need here really.
     //      (b) Don't forget to save the old value of IsDialogCancelEnabled() to
     //          restore it afterwards. We cannot call EnableDialogCancel( sal_False )
@@ -1972,7 +1972,7 @@ void SAL_CALL Frame::dispose() throw( cs
     m_bIsHidden          = sal_True;
 
-    // Disable this instance for further working realy!
+    // Disable this instance for further working really!
     m_aTransactionManager.setWorkingMode( E_CLOSE );
 
@@ -2042,7 +2042,7 @@ css::uno::Reference< css::task::XStatusI
     ReadGuard aReadLock( m_aLock );
 
-    // Make snapshot of neccessary member and define default return value.
+    // Make snapshot of necessary member and define default return value.
     css::uno::Reference< css::task::XStatusIndicator >        xExternal(m_xIndicatorInterception.get(), css::uno::UNO_QUERY);
     css::uno::Reference< css::task::XStatusIndicatorFactory > xFactory = m_xIndicatorFactoryHelper;
@@ -2483,7 +2483,7 @@ void SAL_CALL Frame::disposing( const cs
     if( aEvent.Source == m_xContainerWindow )
     {
-        // NECCESSARY: Impl-method is threadsafe by himself!
+        // NECESSARY: Impl-method is threadsafe by himself!
         aWriteLock.unlock();
         implts_stopWindowListening();
@@ -2858,7 +2858,7 @@ void Frame::implts_setIconOnWindow()
 
 	/* SAFE AREA ----------------------------------------------------------------------------------------------- */
-    // Make snapshot of neccessary members and release lock.
+    // Make snapshot of necessary members and release lock.
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::awt::XWindow >       xContainerWindow( m_xContainerWindow, css::uno::UNO_QUERY );
@@ -2957,7 +2957,7 @@ void Frame::implts_startWindowListening(
 
     /* SAFE AREA ----------------------------------------------------------------------------------------------- */
-    // Make snapshot of neccessary member!
+    // Make snapshot of necessary member!
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::awt::XWindow >                            xContainerWindow    = m_xContainerWindow   ;
@@ -3000,7 +3000,7 @@ void Frame::implts_stopWindowListening()
 
     /* SAFE AREA ----------------------------------------------------------------------------------------------- */
-    // Make snapshot of neccessary member!
+    // Make snapshot of necessary member!
     ReadGuard aReadLock( m_aLock );
     css::uno::Reference< css::awt::XWindow >                            xContainerWindow    = m_xContainerWindow   ;
@@ -3089,7 +3089,7 @@ void Frame::implts_checkSuicide()
                             /*IN*/       sal_Bool                                   bState  )
 {
-    // Note: If start module isnt installed - no closer has to be shown!
+    // Note: If start module isn't installed - no closer has to be shown!
     if (!SvtModuleOptions().IsModuleInstalled(SvtModuleOptions::E_SSTARTMODULE))
         return;
@@ -3180,7 +3180,7 @@ void Frame::impl_checkMenuCloser()
     }
 
-    // Look for neccessary actions ...
+    // Look for necessary actions ...
     // Only if the closer state must be moved from one frame to another one
     // or must be enabled/disabled at all.

Modified: openoffice/trunk/main/framework/source/services/modulemanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/modulemanager.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/services/pathsettings.cxx (original)
+++ openoffice/trunk/main/framework/source/services/pathsettings.cxx Tue Apr 29 19:05:05 2014
@@ -300,7 +300,7 @@ PathSettings::PathInfo PathSettings::imp
 		//sal_Bool bMandatory = ((aInfo.Attributes & css::beans::PropertyAttribute::REMOVEABLE) != css::beans::PropertyAttribute::REMOVEABLE);
     
         // Note: Till we support finalized / mandatory on our API more in detail we handle
         // all states simple as READONLY ! But because all realy needed pathes are "mandatory" by default
         // we have to handle "finalized" as the real "readonly" indicator .
         aPathVal.bIsReadonly = bFinalized;
     }
@@ -318,8 +318,8 @@ void PathSettings::impl_storePath(const 
     css::uno::Reference< css::container::XNameAccess > xCfgOld = fa_getCfgOld();
 
     // try to replace path-parts with well known and uspported variables.
     // So an office can be moved easialy to another location without loosing
     // it's related pathes.
     PathInfo aResubstPath(aPath);
     impl_subst(aResubstPath, sal_True);
 
@@ -340,11 +340,11 @@ void PathSettings::impl_storePath(const 
     ::comphelper::ConfigurationHelper::flush(xCfgNew);
 
     // remove the whole path from the old configuration !
-    // Otherwise we cant make sure that the diff between new and old configuration
-    // on loading time realy represent an user setting !!!
+    // Otherwise we can't make sure that the diff between new and old configuration
+    // on loading time really represent an user setting !!!
 
     // Check if the given path exists inside the old configuration.
     // Because our new configuration knows more then the list of old pathes ... !
     if (xCfgOld->hasByName(aResubstPath.sPathName))
     {
         css::uno::Reference< css::beans::XPropertySet > xProps(xCfgOld, css::uno::UNO_QUERY_THROW);
@@ -404,7 +404,7 @@ PathSettings::EChangeOp PathSettings::im
         aPath = impl_readNewFormat(sPath);
         aPath.sPathName = sPath;
         // replace all might existing variables with real values
         // Do it before these old pathes will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
         impl_subst(aPath, sal_False);
@@ -423,7 +423,7 @@ PathSettings::EChangeOp PathSettings::im
         // can be disabled for a new major
         OUStringList lOldVals = impl_readOldFormat(sPath);
         // replace all might existing variables with real values
         // Do it before these old pathes will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
         impl_subst(lOldVals, fa_getSubstitution(), sal_False);
@@ -433,7 +433,7 @@ PathSettings::EChangeOp PathSettings::im
         { throw exRun; }
     // Normal(!) exceptions can be ignored!
     // E.g. in case an addon installs a new path, which was not well known for an OOo 1.x installation
-    // we cant find a value for it inside the "old" configuration. So a NoSuchElementException
+    // we can't find a value for it inside the "old" configuration. So a NoSuchElementException
     // will be normal .-)
     catch(const css::uno::Exception&)
         {}
@@ -509,8 +509,8 @@ css::uno::Sequence< sal_Int32 > PathSett
     // Why ?
     // The outside code must fire N events for every changed property.
     // And the knowing about packaging of variables of the structure PathInfo
-    // follow these group IDs ! But if such ID isnt in the range of [0..IDGROUP_COUNT]
-    // the outside cant determine the right group ... and cant fire the right events .-)
+    // follow these group IDs ! But if such ID isn't in the range of [0..IDGROUP_COUNT]
+    // the outside can't determine the right group ... and can't fire the right events .-)
 
     css::uno::Sequence< sal_Int32 > lIDs(IDGROUP_COUNT);
     lIDs[0] = IDGROUP_OLDSTYLE       ;
@@ -889,7 +889,7 @@ void PathSettings::impl_setPathValue(   
                     ::rtl::OUStringBuffer sMsg(256);
                     sMsg.appendAscii("The path '"    );
                     sMsg.append     (aChangePath.sPathName);
-                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal pathes cant be set.");
+                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal paths can't be set.");
                     throw css::uno::Exception(sMsg.makeStringAndClear(),
                                               static_cast< ::cppu::OWeakObject* >(this));
                 }
@@ -909,7 +909,7 @@ void PathSettings::impl_setPathValue(   
                     ::rtl::OUStringBuffer sMsg(256);
                     sMsg.appendAscii("The path '"    );
                     sMsg.append     (aChangePath.sPathName);
-                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal pathes cant be set.");
+                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal paths can't be set.");
                     throw css::uno::Exception(sMsg.makeStringAndClear(),
                                               static_cast< ::cppu::OWeakObject* >(this));
                 }
@@ -975,7 +975,7 @@ sal_Bool PathSettings::impl_isValidPath(
 sal_Bool PathSettings::impl_isValidPath(const ::rtl::OUString& sPath) const
 {
     // allow empty path to reset a path.
 // idea by LLA to support empty pathes
 //    if (sPath.getLength() == 0)
 //    {
 //        return sal_True;
@@ -1102,7 +1102,7 @@ css::uno::Reference< css::util::XStringS
     {
         // create the needed substitution service.
         // We must replace all used variables inside readed path values.
-        // In case we can't do so ... the whole office can't work realy.
+        // In case we can't do so ... the whole office can't work really.
         // That's why it seams to be OK to throw a RuntimeException then.
         xSubst = css::uno::Reference< css::util::XStringSubstitution >(
                                 xSMGR->createInstance(SERVICENAME_SUBSTITUTEPATHVARIABLES),
@@ -1135,7 +1135,7 @@ css::uno::Reference< css::container::XNa
                    ::comphelper::ConfigurationHelper::openConfig(
                         xSMGR,
                         CFG_NODE_OLD,
-                        ::comphelper::ConfigurationHelper::E_STANDARD), // not readonly! Somtimes we need write access there !!!
+                        ::comphelper::ConfigurationHelper::E_STANDARD), // not readonly! Sometimes we need write access there !!!
                    css::uno::UNO_QUERY_THROW);
 
         // SAFE ->
@@ -300,7 +300,7 @@ PathSettings::PathInfo PathSettings::imp
     
         // Note: Till we support finalized / mandatory on our API more in detail we handle
-        // all states simple as READONLY ! But because all realy needed pathes are "mandatory" by default
+        // all states simple as READONLY ! But because all really needed paths are "mandatory" by default
         // we have to handle "finalized" as the real "readonly" indicator .
         aPathVal.bIsReadonly = bFinalized;
@@ -318,8 +318,8 @@ void PathSettings::impl_storePath(const 
 
     // try to replace path-parts with well known and uspported variables.
-    // So an office can be moved easialy to another location without loosing
-    // it's related pathes.
+    // So an office can be moved easialy to another location without losing
+    // it's related paths.
     PathInfo aResubstPath(aPath);
     impl_subst(aResubstPath, sal_True);
@@ -340,11 +340,11 @@ void PathSettings::impl_storePath(const 
 
     // Check if the given path exists inside the old configuration.
-    // Because our new configuration knows more then the list of old pathes ... !
+    // Because our new configuration knows more then the list of old paths ... !
     if (xCfgOld->hasByName(aResubstPath.sPathName))
     {
@@ -404,7 +404,7 @@ PathSettings::EChangeOp PathSettings::im
         aPath.sPathName = sPath;
         // replace all might existing variables with real values
-        // Do it before these old pathes will be compared against the
+        // Do it before these old paths will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
@@ -423,7 +423,7 @@ PathSettings::EChangeOp PathSettings::im
         OUStringList lOldVals = impl_readOldFormat(sPath);
         // replace all might existing variables with real values
-        // Do it before these old pathes will be compared against the
+        // Do it before these old paths will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
@@ -975,7 +975,7 @@ sal_Bool PathSettings::impl_isValidPath(
 {
     // allow empty path to reset a path.
-// idea by LLA to support empty pathes
+// idea by LLA to support empty paths
 //    if (sPath.getLength() == 0)
 //    {

Modified: openoffice/trunk/main/framework/source/services/substitutepathvars.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/services/substitutepathvars.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/xml/imagesdocumenthandler.cxx (original)
+++ openoffice/trunk/main/framework/source/xml/imagesdocumenthandler.cxx Tue Apr 29 19:05:05 2014
@@ -204,7 +204,7 @@ throw(	SAXException, RuntimeException )
 				if ( m_bImageContainerStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:imagecontainer' cannot be embeded into 'image:imagecontainer'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:imagecontainer' cannot be embedded into 'image:imagecontainer'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -217,14 +217,14 @@ throw(	SAXException, RuntimeException )
 				if ( !m_bImageContainerStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:images' must be embeded into element 'image:imagecontainer'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:images' must be embedded into element 'image:imagecontainer'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
 				if ( m_bImagesStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:images' cannot be embeded into 'image:images'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:images' cannot be embedded into 'image:images'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -321,14 +321,14 @@ throw(	SAXException, RuntimeException )
 
 			case IMG_ELEMENT_ENTRY:
 			{
 				// Check that image:entry is embeded into image:images!
 				if ( !m_bImagesStartFound )
 				{
 					delete m_pImages;
 					m_pImages = NULL;
 
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:entry' must be embeded into element 'image:images'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:entry' must be embedded into element 'image:images'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -398,25 +398,25 @@ throw(	SAXException, RuntimeException )
 
 			case IMG_ELEMENT_EXTERNALIMAGES:
 			{
 				// Check that image:externalimages is embeded into image:imagecontainer
 				if ( !m_bImageContainerStartFound )
 				{
 					delete m_pImages;
 					m_pImages = NULL;
 
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalimages' must be embeded into element 'image:imagecontainer'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalimages' must be embedded into element 'image:imagecontainer'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
 				// Check that image:externalentry is NOT embeded into image:externalentry
 				if ( m_bExternalImagesStartFound )
 				{
 					delete m_pImages;
 					m_pImages = NULL;
 
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalimages' cannot be embeded into 'image:externalimages'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalimages' cannot be embedded into 'image:externalimages'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -436,7 +436,7 @@ throw(	SAXException, RuntimeException )
 					m_pExternalImages = NULL;
 
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalentry' must be embeded into 'image:externalimages'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalentry' must be embedded into 'image:externalimages'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -448,7 +448,7 @@ throw(	SAXException, RuntimeException )
 					m_pExternalImages = NULL;
 
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalentry' cannot be embeded into 'image:externalentry'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'image:externalentry' cannot be embedded into 'image:externalentry'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -321,14 +321,14 @@ throw(	SAXException, RuntimeException )
 			case IMG_ELEMENT_ENTRY:
 			{
-				// Check that image:entry is embeded into image:images!
+				// Check that image:entry is embedded into image:images!
 				if ( !m_bImagesStartFound )
 				{
@@ -398,25 +398,25 @@ throw(	SAXException, RuntimeException )
 			case IMG_ELEMENT_EXTERNALIMAGES:
 			{
-				// Check that image:externalimages is embeded into image:imagecontainer
+				// Check that image:externalimages is embedded into image:imagecontainer
 				if ( !m_bImageContainerStartFound )
 				{
@@ -398,25 +398,25 @@ throw(	SAXException, RuntimeException )
 				}
 
-				// Check that image:externalentry is NOT embeded into image:externalentry
+				// Check that image:externalentry is NOT embedded into image:externalentry
 				if ( m_bExternalImagesStartFound )
 				{

Modified: openoffice/trunk/main/framework/test/test.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/test/test.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================